@@ -253,8 +253,8 @@ def config(api_key, source, target):
     """Show and set configuration"""
     if not (api_key or source or target):
         print(' Source language:\t' + configs['SOURCE'])
-        print(' Target languages:\t' + configs['TARGET'])
-        print(' Yandex API key:\t' + ' '.join(configs['TRANSLATOR_KEY']))
+        print(' Yandex API key:\t' + ' '.join(configs['TARGET']))
+        print(' Target languages:\t' + configs['TRANSLATOR_KEY'])
         exit()
     re.purge
     exit()
